<?php
/**
 *
 * This file is part of the phpBB Forum Software package.
 *
 * @copyright (c) phpBB Limited <https://www.phpbb.com>
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 * For full copyright and license information, please see
 * the docs/CREDITS.txt file.
 *
 */

namespace phpbb\ban\type;

use phpbb\ban\exception\no_valid_ips_exception;
use Symfony\Component\HttpFoundation\IpUtils;

class ip extends base
{

	/**
	 * @inheritDoc
	 */
	public function get_type(): string
	{
		return 'ip';
	}

	/**
	 * @inheritDoc
	 */
	public function get_user_column(): ?string
	{
		return 'user_ip';
	}

	/**
	 * {@inheritDoc}
	 */
	public function check(array $ban_rows, array $user_data)
	{
		return parent::check($ban_rows, $user_data); // TODO: Change the autogenerated stub
	}

	/**
	 * @inheritDoc
	 */
	public function prepare_for_storage(array $items): array
	{
		$ban_items = [];
		foreach ($items as $ip)
		{
			try
			{
				// Misuse checkIp for checking validity of IP. Should return true if defined IP is valid.
				if (!IpUtils::checkIp($ip, $ip))
				{
					continue;
				}

				$ban_items[] = $ip;
			}
			catch (\RuntimeException $exception)
			{
				// IPv6 not supported, therefore IPv6 address will not be added
			}
		}

		if (empty($ban_items))
		{
			throw new no_valid_ips_exception(); // TODO
		}

		return $ban_items;
	}
}
